function varargout = guide_uicontextmenu(varargin)
% GUIDE_UICONTEXTMENU M-file for guide_uicontextmenu.fig
%      GUIDE_UICONTEXTMENU, by itself, creates a new GUIDE_UICONTEXTMENU or raises the existing
%      singleton*.
%
%      H = GUIDE_UICONTEXTMENU returns the handle to a new GUIDE_UICONTEXTMENU or the handle to
%      the existing singleton*.
%
%      GUIDE_UICONTEXTMENU('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUIDE_UICONTEXTMENU.M with the given input arguments.
%
%      GUIDE_UICONTEXTMENU('Property','Value',...) creates a new GUIDE_UICONTEXTMENU or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before guide_uicontextmenu_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to guide_uicontextmenu_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help guide_uicontextmenu

% Last Modified by GUIDE v2.5 26-Jun-2002 20:39:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @guide_uicontextmenu_OpeningFcn, ...
                   'gui_OutputFcn',  @guide_uicontextmenu_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before guide_uicontextmenu is made visible.
function guide_uicontextmenu_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to guide_uicontextmenu (see VARARGIN)

% Choose default command line output for guide_uicontextmenu
handles.output = hObject;

%% added code to plot a line
handles.hline = plot(1:10);
set(handles.hline, 'UIContextMenu', handles.cmenu)

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes guide_uicontextmenu wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = guide_uicontextmenu_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --------------------------------------------------------------------
function cmenu_Callback(hObject, eventdata, handles)
% hObject    handle to cmenu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --------------------------------------------------------------------
function cm_dashed_Callback(hObject, eventdata, handles)
% hObject    handle to cm_dashed (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
set(handles.hline, 'linestyle', '--')

% --------------------------------------------------------------------
function cm_dotted_Callback(hObject, eventdata, handles)
% hObject    handle to cm_dotted (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
set(handles.hline, 'linestyle', ':')

% --------------------------------------------------------------------
function cm_solid_Callback(hObject, eventdata, handles)
% hObject    handle to cm_solid (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
set(handles.hline, 'linestyle', '-')

